@@ -132,8 +132,12 @@ class Base():
         tof = float(procpar['procpar']['tof']['values'][0])
         rt = at+d1
         nt = numpy.array(
-            [procpar['procpar']['nt']['values']], dtype=int)
-        acqtime = (nt*rt).cumsum()/60.  # convert to mins.
+            [procpar['procpar']['nt']['values']], dtype=int).flatten()
+        acqtime = numpy.zeros(nt.shape)
+        acqtime[0] = (rt * nt[0] / 2)
+        for i in range(1, len(nt)):
+            acqtime[i] = acqtime[i - 1] + (nt[i - 1] + nt[i]) / 2 * rt
+        acqtime /= 60.   # convert to min
         sw_hz = float(procpar['procpar']['sw']['values'][0])
         sw = round(sw_hz/reffrq, 2)
         sw_left = (0.5+1e6*(sfrq-reffrq)/sw_hz)*sw_hz/sfrq
@@ -175,11 +179,13 @@ class Base():
         at = procpar['acqus']['TD']/(2*sw_hz)
         rt = at+d1
         td = procpar['tdelta']
-        ts = procpar['tstart']
+        cumulative = procpar['tcum']
+        single = procpar['tsingle']
+        tstart = cumulative - 0.5*single    # tstart for acquisition
         al = procpar['arraylength']
         a = procpar['arrayset']
         acqtime = numpy.zeros((al))
-        acqtime[0] = ts[a-1]
+        acqtime[0] = tstart[a-1]
         for i in range(1, al):
             acqtime[i] = acqtime[i-1] + td
         params = dict(
@@ -409,6 +415,26 @@ class Fid(Base):
         for plot in plots:
             delattr(self, plot.id)
 
+    def _get_widgets(self):
+        """
+        Return a list of all widget objects (peak selection, etc.) owned by this :class:`~nmrpy.data_objects.Fid`.
+        """
+        widgets = [
+            id for id in sorted(self.__dict__)
+            if isinstance(self.__dict__[id], Phaser)
+            or isinstance(self.__dict__[id], Calibrator)
+            or isinstance(self.__dict__[id], DataPeakSelector)
+            or isinstance(self.__dict__[id], FidRangeSelector)
+        ]
+        return widgets
+
+    def _del_widgets(self):
+        """
+        Deletes all widget objects (peak selection, etc.) owned by this :class:`~nmrpy.data_objects.Fid`.
+        """
+        widgets = self._get_widgets()
+        for w in widgets:
+            delattr(self, w)
 
     @classmethod
     def _is_valid_dataset(cls, data):
@@ -637,7 +663,7 @@ class Fid(Base):
         if not Fid._is_flat_iter(self.data):
             raise AttributeError('data must be 1 dimensional.')
         global _phaser_widget
-        _phaser_widget = Phaser(self)
+        self._phaser_widget = Phaser(self)
 
     def calibrate(self):
         """
@@ -650,7 +676,7 @@ class Fid(Base):
 Left - select peak
 '''
         plot_title = "Calibration {}".format(self.id)
-        _calibrate_widget = Calibrator(self,
+        self._calibrate_widget = Calibrator(self,
                             title=plot_title,
                             label=plot_label,
                             )
@@ -722,11 +748,23 @@ Ctrl+Right - delete range
 Ctrl+Alt+Right - assign
 '''
         plot_title = "Peak-picking {}".format(self.id)
-        _peakpicker_widget = DataPeakSelector(self,
+        self._peakpicker_widget = DataPeakSelector(self,
                             title=plot_title,
                             label=plot_label,
                             )
 
+    def clear_peaks(self):
+        """
+        Clear peaks stored in :attr:`~nmrpy.data_objects.Fid.peaks`.
+        """
+        self.peaks = None
+
+    def clear_ranges(self):
+        """
+        Clear ranges stored in :attr:`~nmrpy.data_objects.Fid.ranges`.
+        """
+        self.ranges = None
+
     def baseliner(self):
         """
         Instantiate a baseline-correction GUI widget. Right-click-dragging
@@ -743,7 +781,7 @@ Ctrl+Right - delete range
 Ctrl+Alt+Right - assign
 '''
         plot_title = "Baseline correction {}".format(self.id)
-        _baseliner_widget = FidRangeSelector(self,
+        self._baseliner_widget = FidRangeSelector(self,
                                 title=plot_title,
                                 label=plot_label,
                                 )
@@ -1208,6 +1246,29 @@ class FidArray(Base):
         for plot in plots:
             delattr(self, plot.id)
 
+    def _get_widgets(self):
+        """
+        Return a list of all widget objects (peak selection, etc.) owned by this :class:`~nmrpy.data_objects.FidArray`.
+        """
+        widgets = [
+            id for id in sorted(self.__dict__)
+            if isinstance(self.__dict__[id], Phaser)
+            or isinstance(self.__dict__[id], RangeCalibrator)
+            or isinstance(self.__dict__[id], DataPeakRangeSelector)
+            or isinstance(self.__dict__[id], FidArrayRangeSelector)
+            or isinstance(self.__dict__[id], DataTraceRangeSelector)
+            or isinstance(self.__dict__[id], DataTraceSelector)
+        ]
+        return widgets
+
+    def _del_widgets(self):
+        """
+        Deletes all widget objects (peak selection, etc.) owned by this :class:`~nmrpy.data_objects.Fid`.
+        """
+        widgets = self._get_widgets()
+        for w in widgets:
+            delattr(self, w)
+
     @property
     def data(self):
         """
@@ -1272,6 +1333,11 @@ class FidArray(Base):
         """
         if hasattr(self, fid_id):
             if isinstance(getattr(self, fid_id), Fid):
+                fids = [f.id for f in self.get_fids()]
+                idx = fids.index(fid_id)
+                at = list(self._params['acqtime'])
+                at.pop(idx)
+                self._params['acqtime'] = at
                 delattr(self, fid_id)
             else:
                 raise AttributeError('{} is not an FID object.'.format(fid_id))
@@ -1452,7 +1518,7 @@ Ctrl+Right - delete range
 Ctrl+Alt+Right - assign
 '''
         plot_title = 'Select data for baseline-correction'
-        _baseliner_widget = FidArrayRangeSelector(self, title=plot_title, label=plot_label, voff=0.01)
+        self._baseliner_widget = FidArrayRangeSelector(self, title=plot_title, label=plot_label, voff=0.01)
   
     def baseline_correct_fids(self, deg=2):
         """ 
@@ -1643,7 +1709,6 @@ Ctrl+Alt+Right - assign
         """
         plt = Plot()
         plt._plot_deconv_array(self.get_fids(), 
-            summed_peak_filled=True,
             **kwargs)
         setattr(self, plt.id, plt)
         
@@ -1673,7 +1738,7 @@ Ctrl+Alt+Right - assign
 '''
 Left - select peak
 '''
-        _calibrate_widget = RangeCalibrator(self,
+        self._calibrate_widget = RangeCalibrator(self,
                             y_indices=fid_number,
                             aoti=assign_only_to_index,
                             voff=voff, 
@@ -1709,7 +1774,7 @@ Drag Right - select range
 Ctrl+Right - delete range
 Ctrl+Alt+Right - assign
 '''
-        _peakpicker_widget = DataPeakRangeSelector(self, 
+        self._peakpicker_widget = DataPeakRangeSelector(self,
                 y_indices=fid_number,
                 aoti=assign_only_to_index,
                 voff=voff, 
@@ -1739,14 +1804,30 @@ Drag Right - select range
 Ctrl+Right - delete range
 Ctrl+Alt+Right - assign
 '''
-        _peakpicker_widget = DataTraceRangeSelector(
+        self._peakpicker_widget = DataTraceRangeSelector(
             self,
             voff=voff,
             lw=lw,
             label=plot_label,
             )
 
-    def _generate_trace_mask(self, traces): 
+    def clear_peaks(self):
+        """
+        Calls :meth:`~nmrpy.data_objects.Fid.clear_peaks` on every :class:`~nmrpy.data_objects.Fid`
+        object in this :class:`~nmrpy.data_objects.FidArray`.
+        """
+        for fid in self.get_fids():
+            fid.peaks = None
+
+    def clear_ranges(self):
+        """
+        Calls :meth:`~nmrpy.data_objects.Fid.clear_ranges` on every :class:`~nmrpy.data_objects.Fid`
+        object in this :class:`~nmrpy.data_objects.FidArray`.
+        """
+        for fid in self.get_fids():
+            fid.ranges = None
+
+    def _generate_trace_mask(self, traces):
         ppm = [numpy.round(numpy.mean(i[0]), 2) for i in traces]
         self._trace_mean_ppm = ppm
         tt = [i[1] for i in traces]
@@ -1848,7 +1929,7 @@ Right - finalize trace
 Ctrl+Left - delete nearest trace
 Ctrl+Alt+Right - assign
 '''
-        _select_trace_widget = DataTraceSelector(self, 
+        self._select_trace_widget = DataTraceSelector(self,
             extra_data=peakshapes, 
             extra_data_colour='b', 
             voff=voff, 
@@ -1878,21 +1959,33 @@ Ctrl+Alt+Right - assign
             integrals_set[i] = integrals    
         return integrals_set
 
-    def save_to_file(self, filename=None):
+    def save_to_file(self, filename=None, overwrite=False):
         """
         Save :class:`~nmrpy.data_objects.FidArray` object to file, including all objects owned.
 
         :keyword filename: filename to save :class:`~nmrpy.data_objects.FidArray` to
 
+        :keyword overwrite: if True, overwrite existing file
+
         """
         if filename is None:
-            filename = 'data.nmrpy'
+            basename = os.path.split(os.path.splitext(self.fid_path)[0])[-1]
+            filename = basename+'.nmrpy'
         if not isinstance(filename, str):
             raise TypeError('filename must be a string.')
-        #delete all matplotlib plots to reduce file size
+        if filename[-6:] != '.nmrpy':
+            filename += '.nmrpy'
+        if os.path.isfile(filename) and not overwrite:
+            print('File '+filename+' exists, set overwrite=True to force.')
+            return 1
+        # delete all matplotlib plots to reduce file size
         self._del_plots()
         for fid in self.get_fids():
             fid._del_plots()
+        # delete all widgets (can't be pickled)
+        self._del_widgets()
+        for fid in self.get_fids():
+            fid._del_widgets()
         with open(filename, 'wb') as f:
             pickle.dump(self, f)
   
@@ -1981,7 +2074,7 @@ class BrukerImporter(Importer):
                     break
                 if alldata[incr][1].shape == alldata[0][1].shape:
                     break
-                incr +=1
+                incr += 1
             if incr > 1:
                 if arrayset == None:
                     print('Total of '+str(incr)+' alternating FidArrays found.')
@@ -2001,7 +2094,8 @@ class BrukerImporter(Importer):
             self._procpar = procpar
             self._file_format = 'bruker'
             self.data = nmrglue.bruker.remove_digital_filter(procpar, self.data)
-            self._procpar['tdelta'], self._procpar['tstart'] = self._get_time_delta()
+            self._procpar['tdelta'], self._procpar['tcum'],\
+                    self._procpar['tsingle'] = self._get_time_delta()
             self._procpar['arraylength'] = self.data.shape[0]
             self._procpar['arrayset'] = arrayset
         except FileNotFoundError:
@@ -2011,16 +2105,19 @@ class BrukerImporter(Importer):
             
     def _get_time_delta(self):
         td = 0.0
-        start = []
+        tcum = []
+        tsingle = []
         for i in range(self.incr):
             pp = self.alldata[i][0]['acqus']
             sw_hz = pp['SW_h']
             at = pp['TD']/(2*sw_hz)
             d1 = pp['RD']
             nt = pp['NS']
-            td += (at+d1)*nt/60. # convert to mins
-            start.append(td)
-        return (td, start)
+            tot = (at+d1)*nt/60.   # convert to mins
+            td += tot
+            tcum.append(td)
+            tsingle.append(tot)
+        return (td, numpy.array(tcum), numpy.array(tsingle))
 
 if __name__ == '__main__':
     pass
